Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfiguredExternalCommand ¶
func ConfiguredExternalCommand() string
ConfiguredExternalCommand returns the external command that should be used to open the editor.
This is either the value of the EDITOR environment variable, or "vim" if that is not set.
func OpenExternal ¶
OpenExternal opens the external editor and returns a command that will wait for it to finish.
The buffer is the initial contents of the file.
Types ¶
type ExternalFinishedMsg ¶
ExternalFinishedMsg is a message that is sent when the external editor finishes (either successfully or with an error). The buffer is the contents of the file that was edited.
Click to show internal directories.
Click to hide internal directories.